==> ovirt-engine-3.5.6.2.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/irsbroker/SetVolumeDescriptionVDSCommand.java <==
package org.ovirt.engine.core.vdsbroker.irsbroker;

import org.ovirt.engine.core.common.vdscommands.SetVolumeDescriptionVDSCommandParameters;
import org.ovirt.engine.core.utils.log.Log;
import org.ovirt.engine.core.utils.log.LogFactory;
import org.ovirt.engine.core.vdsbroker.vdsbroker.VDSExceptionBase;

public class SetVolumeDescriptionVDSCommand<P extends SetVolumeDescriptionVDSCommandParameters> extends IrsBrokerCommand<P> {
    private final static Log log = LogFactory.getLog(SetVolumeDescriptionVDSCommand.class);

    public SetVolumeDescriptionVDSCommand(P parameters) {
        super(parameters);
    }

    @Override
    protected void executeIrsBrokerCommand() {
        log.info("-- executeIrsBrokerCommand: calling 'setVolumeDescription' ");
        log.infoFormat("-- setVolumeDescription parameters:" + "\r\n"
                + "                spUUID={0}" + "\r\n"
                + "                sdUUID={1}" + "\r\n"
                + "                imageGroupGUID={2}" + "\r\n"
                + "                volUUID={3}" + "\r\n"
                + "                description={4}" + "\r\n",
                getParameters().getStoragePoolId().toString(),
                getParameters().getStorageDomainId().toString(),
                getParameters().getImageGroupId().toString(),
                getParameters().getImageId().toString(),
                getParameters().getDescription());

        status = getIrsProxy().setVolumeDescription(
                getParameters().getStorageDomainId().toString(),
                getParameters().getStoragePoolId().toString(),
                getParameters().getImageGroupId().toString(),
                getParameters().getImageId().toString(),
                getParameters().getDescription());

        proceedProxyReturnValue();
    }

    @Override
    protected VDSExceptionBase createDefaultConcreteException(String errorMessage) {
        return new IrsOperationFailedNoFailoverException(errorMessage);
    }
}

==> ovirt-engine-3.6.4.1.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/irsbroker/SetVolumeDescriptionVDSCommand.java <==
package org.ovirt.engine.core.vdsbroker.irsbroker;

import org.ovirt.engine.core.common.vdscommands.SetVolumeDescriptionVDSCommandParameters;
import org.ovirt.engine.core.vdsbroker.vdsbroker.VDSExceptionBase;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SetVolumeDescriptionVDSCommand<P extends SetVolumeDescriptionVDSCommandParameters> extends IrsBrokerCommand<P> {
    private final static Logger log = LoggerFactory.getLogger(SetVolumeDescriptionVDSCommand.class);

    public SetVolumeDescriptionVDSCommand(P parameters) {
        super(parameters);
    }

    @Override
    protected void executeIrsBrokerCommand() {
        log.info("-- executeIrsBrokerCommand: calling 'setVolumeDescription', parameters:");
        log.info("++ spUUID={}", getParameters().getStoragePoolId());
        log.info("++ sdUUID={}", getParameters().getStorageDomainId());
        log.info("++ imageGroupGUID={}", getParameters().getImageGroupId());
        log.info("++ volUUID={}", getParameters().getImageId());
        log.info("++ description={}", getParameters().getDescription());

        status = getIrsProxy().setVolumeDescription(
                getParameters().getStorageDomainId().toString(),
                getParameters().getStoragePoolId().toString(),
                getParameters().getImageGroupId().toString(),
                getParameters().getImageId().toString(),
                getParameters().getDescription());

        proceedProxyReturnValue();
    }

    @Override
    protected VDSExceptionBase createDefaultConcreteException(String errorMessage) {
        return new IrsOperationFailedNoFailoverException(errorMessage);
    }
}
